.form-row.field-body .readonly,
.form-row.field-raw_request .readonly,
.form-row.field-raw_response .readonly,
.form-row .field-name > p,
.form-row .field-value > p {
  font-family: monospace;
  white-space: pre-wrap;
}
